@@ -1,13 +1,13 @@
 var indexSectionsWithContent =
 {
-  0: "dlw",
+  0: "bdlw",
   1: "l",
   2: "l",
   3: "w",
   4: "w",
   5: "w",
   6: "lw",
-  7: "d"
+  7: "bd"
 };
 
 var indexSectionNames =
